==> haskell-sorted-list-0.2.2.0-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sorted-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sorted-list
version:              0.2.2.0
visibility:           public
id:                   sorted-list-0.2.2.0-5gvI3TxvI1l28SUYOFwV6c
key:                  sorted-list-0.2.2.0-5gvI3TxvI1l28SUYOFwV6c
license:              BSD-3-Clause
maintainer:           Daniel Casanueva (daniel.casanueva `at` proton.me)
author:               Daniel Casanueva (daniel.casanueva `at` proton.me)
synopsis:             Type-enforced sorted lists and related functions.
description:
    Type-enforced sorted lists and related functions.

    These are useful for:

    * Constraining the argument of a function to be a sorted list
    by stating in your type that the input list is a sorted list.

    * Avoiding sorting a list twice.

    * Creating a list that is sorted from the moment of its construction,
    so it doesn'\''t have to be sorted later.

    * Performing list operations keeping the input list sorted.

    * Improving those list operations that can be
    benefited from the ordering of its elements.

    * Creating infinite lists that are sorted!

    * And more!

    If you are missing a feature, do not hesitate
    to ask by opening an issue at the bug-tracker.

category:             Data
abi:                  cdf7c09c88a261d62cce807d48f2f29f
exposed:              True
exposed-modules:      Data.SortedList
import-dirs:          /usr/lib/ghc-9.2.8/site-local/sorted-list-0.2.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/sorted-list-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sorted-list
hs-libraries:         HSsorted-list-0.2.2.0-5gvI3TxvI1l28SUYOFwV6c
depends:              base-4.16.4.0 deepseq-1.4.6.1
haddock-interfaces:   /usr/share/doc/haskell-sorted-list/html/sorted-list.haddock
haddock-html:         /usr/share/doc/haskell-sorted-list/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sorted-list-0.2.2.0-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sorted-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sorted-list
version:              0.2.2.0
visibility:           public
id:                   sorted-list-0.2.2.0-FJWsJE3CTdQ9jNb8JMYLXj
key:                  sorted-list-0.2.2.0-FJWsJE3CTdQ9jNb8JMYLXj
license:              BSD-3-Clause
maintainer:           Daniel Casanueva (daniel.casanueva `at` proton.me)
author:               Daniel Casanueva (daniel.casanueva `at` proton.me)
synopsis:             Type-enforced sorted lists and related functions.
description:
    Type-enforced sorted lists and related functions.

    These are useful for:

    * Constraining the argument of a function to be a sorted list
    by stating in your type that the input list is a sorted list.

    * Avoiding sorting a list twice.

    * Creating a list that is sorted from the moment of its construction,
    so it doesn'\''t have to be sorted later.

    * Performing list operations keeping the input list sorted.

    * Improving those list operations that can be
    benefited from the ordering of its elements.

    * Creating infinite lists that are sorted!

    * And more!

    If you are missing a feature, do not hesitate
    to ask by opening an issue at the bug-tracker.

category:             Data
abi:                  03783c2f8ffe2af86bebd01eace18d70
exposed:              True
exposed-modules:      Data.SortedList
import-dirs:          /usr/lib/ghc-9.2.8/site-local/sorted-list-0.2.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/sorted-list-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sorted-list
hs-libraries:         HSsorted-list-0.2.2.0-FJWsJE3CTdQ9jNb8JMYLXj
depends:              base-4.16.4.0 deepseq-1.4.6.1
haddock-interfaces:   /usr/share/doc/haskell-sorted-list/html/sorted-list.haddock
haddock-html:         /usr/share/doc/haskell-sorted-list/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
